#ifndef ASM_E2K_LABEL_H
#define ASM_E2K_LABEL_H

#include "macro.h"
#include <stdint.h>

NAMESPACE_ASM_E2K_BEGIN

#ifndef ASM_E2K_LABEL
typedef struct Label
{
    int32_t offset_ : 31;
    bool bound_   : 1;

#ifdef __cplusplus

    // Disable assignment operator
    void operator =(const Label* label);
    static const int32_t INVALID_OFFSET = -2;

    Label() : offset_(INVALID_OFFSET), bound_(false) { }

    bool bound() const {
        return bound_;
    }

    int32_t offset() const {
        ASM_E2K_ASSERT(bound() || used());
        return offset_;
    }

    // Returns whether the label is not bound, but has incoming uses.
    bool used() const {
        return !bound() && offset_ > INVALID_OFFSET;
    }
    // Binds the label, fixing its final position in the code stream.
    void bind(int32_t offset) {
        ASM_E2K_ASSERT(!bound());
        offset_ = offset;
        bound_ = true;
        ASM_E2K_ASSERT(offset_ == offset && "offset fits in 31 bits");
    }
    // Marks the label as neither bound nor used.
    void reset() {
        offset_ = INVALID_OFFSET;
        bound_ = false;
    }
    // Sets the label's latest used position, returning the old use position in
    // the process.
    int32_t use(int32_t offset) {
        ASM_E2K_ASSERT(!bound());

        int32_t old = offset_;
        offset_ = offset;
        ASM_E2K_ASSERT(offset_ == offset && "offset fits in 31 bits");

        return old;
    }
#endif // __cplusplus
} Label;

#else
    typedef ASM_E2K_LABEL Label;
#endif // ASM_E2K_LABEL

NAMESPACE_ASM_E2K_END

#define ASM_E2K_END_OF_LIST 0x0fffffff

#endif // ASM_E2K_LABEL_H