#ifndef TANGO_LIVE_ANALYSER
#define TANGO_LIVE_ANALYSER

#include "tango/compile_phase.hpp"

namespace tango {

//----------------------------------------------------------------------------//

class LiveAnalyser : public CompilePhase {
public:
  LiveAnalyser(Ir* ir, PhaseName name = PhaseName::LAN) : CompilePhase(ir, name), current(nullptr), handle_pr(false) {}
  void          buildPredicateGraph();
  void          buildLiveSets(Block*);
  void          initLiveSet(Block*);
  void          updateLiveSet(Inst*); // Process separate inst (not in bundle).
  void          defLiveSet(Inst*);
  void          useLiveSet(Inst*);
  void          touchLiveSet(Inst*);
  void          pushPreds(Block*);
  bool          isDead(Inst*);
  bool          isDead(Opnd*);
  virtual void  iterate() {}

protected:
  virtual void run_internal();

private:
  void buildLiveSetsByBundles(BundleList&);
  void buildLiveSetsByInsts(InstList&);
  void buildLiveSetsByBundle(Bundle*);
  void updatePrMask(RegOpnd*, bool, RegOpnd*, bool);

public:
  BlockList     work_set;
  LiveSet       live_in_set;
  LiveSet       live_out_set;
  PrSet         pr_in_set;
  PrSet         pr_out_set;
  Block*        current;
  bool          handle_pr;
  int32_t       pr_count;
};

//----------------------------------------------------------------------------//

}      // namespace tango
#endif // TANGO_LIVE_ANALYSER
