#ifndef OPCODES_E2K_CC
#define OPCODES_E2K_CC

#include "opcodes-e2k.h"
#include "latency.h"

namespace asm_e2k {

const ALUInfo alu_info[] = {
    { "ADDd", 		OPC_ADDd, 		EU_AL_012345, 	OUT_REG_LAT_0I, 	IN_REG_LAT_I }, // [0x0] == 0x11
    { "ADDs", 		OPC_ADDs, 		EU_AL_012345, 	OUT_REG_LAT_0I, 	IN_REG_LAT_I }, // [0x1] == 0x10
    { "ANDd", 		OPC_ANDd, 		EU_AL_012345, 	OUT_REG_LAT_0I, 	IN_REG_LAT_I }, // [0x2] == 0x1
    { "ANDNd", 		OPC_ANDNd, 		EU_AL_012345, 	OUT_REG_LAT_0I, 	IN_REG_LAT_I }, // [0x3] == 0x3
    { "ANDNs", 		OPC_ANDNs, 		EU_AL_012345, 	OUT_REG_LAT_0I, 	IN_REG_LAT_I }, // [0x4] == 0x2
    { "ANDs", 		OPC_ANDs, 		EU_AL_012345, 	OUT_REG_LAT_0I, 	IN_REG_LAT_I }, // [0x5] == 0x0
    { "BITREVd", 	OPC_BITREVd, 	EU_AL_0134, 	OUT_REG_LAT_0I, 	IN_REG_LAT_I }, // [0x6] == 0x27
    { "BITREVs", 	OPC_BITREVs, 	EU_AL_0134, 	OUT_REG_LAT_0I, 	IN_REG_LAT_I }, // [0x7] == 0x26
    { "CCTOB", 		OPC_CCTOB, 		EU_AL_03, 		OUT_REG_LAT_PRI, 	IN_REG_LAT_I }, // [0x8] == 0x24
    { "CMPANDdb", 	OPC_CMPANDdb, 	EU_AL_0134, 	OUT_REG_LAT_PRI, 	IN_REG_LAT_I }, // [0x9] == 0x23
    { "CMPANDsb", 	OPC_CMPANDsb, 	EU_AL_0134, 	OUT_REG_LAT_PRI, 	IN_REG_LAT_I }, // [0xa] == 0x22
    { "CMPdb", 		OPC_CMPdb, 		EU_AL_0134, 	OUT_REG_LAT_PRI, 	IN_REG_LAT_I }, // [0xb] == 0x21
    { "CMPsb", 		OPC_CMPsb, 		EU_AL_0134, 	OUT_REG_LAT_PRI, 	IN_REG_LAT_I }, // [0xc] == 0x20
    { "DRTOAP", 	OPC_DRTOAP, 	EU_AL_0134, 	OUT_REG_LAT_1A, 	IN_REG_LAT_I }, // [0xd] == 0x62
    { "FADDd", 		OPC_FADDd, 		EU_AL_0134, 	OUT_REG_LAT_4F, 	IN_REG_LAT_F }, // [0xe] == 0x31
    { "FADDs", 		OPC_FADDs, 		EU_AL_0134, 	OUT_REG_LAT_4F, 	IN_REG_LAT_F }, // [0xf] == 0x30
    { "FCMPdb", 	OPC_FCMPdb, 	EU_AL_0134, 	OUT_REG_LAT_PRF, 	IN_REG_LAT_F }, // [0x10] == 0x2f
    { "FCMPsb", 	OPC_FCMPsb, 	EU_AL_0134, 	OUT_REG_LAT_PRF, 	IN_REG_LAT_F }, // [0x11] == 0x2e
    { "FDTOD", 		OPC_FDTOD, 		EU_AL_0134, 	OUT_REG_LAT_5F, 	IN_REG_LAT_F }, // [0x12] == 0x3d
    { "FDTOS", 		OPC_FDTOS, 		EU_AL_0134, 	OUT_REG_LAT_5F, 	IN_REG_LAT_F }, // [0x13] == 0x3f
    { "FMAXd", 		OPC_FMAXd, 		EU_AL_0134, 	OUT_REG_LAT_2M, 	IN_REG_LAT_F }, // [0x14] == 0x37
    { "FMAXs", 		OPC_FMAXs, 		EU_AL_0134, 	OUT_REG_LAT_2M, 	IN_REG_LAT_F }, // [0x15] == 0x36
    { "FMINd", 		OPC_FMINd, 		EU_AL_0134, 	OUT_REG_LAT_2M, 	IN_REG_LAT_F }, // [0x16] == 0x35
    { "FMINs", 		OPC_FMINs, 		EU_AL_0134, 	OUT_REG_LAT_2M, 	IN_REG_LAT_F }, // [0x17] == 0x34
    { "FMULd", 		OPC_FMULd, 		EU_AL_0134, 	OUT_REG_LAT_4F, 	IN_REG_LAT_F }, // [0x18] == 0x39
    { "FMULs", 		OPC_FMULs, 		EU_AL_0134, 	OUT_REG_LAT_4F, 	IN_REG_LAT_F }, // [0x19] == 0x38
    { "FSTOD", 		OPC_FSTOD, 		EU_AL_0134, 	OUT_REG_LAT_5F, 	IN_REG_LAT_F }, // [0x1a] == 0x3e
    { "FSTOS", 		OPC_FSTOS, 		EU_AL_0134, 	OUT_REG_LAT_5F, 	IN_REG_LAT_F }, // [0x1b] == 0x3c
    { "FSUBd", 		OPC_FSUBd, 		EU_AL_0134, 	OUT_REG_LAT_4F, 	IN_REG_LAT_F }, // [0x1c] == 0x33
    { "FSUBs", 		OPC_FSUBs, 		EU_AL_0134, 	OUT_REG_LAT_4F, 	IN_REG_LAT_F }, // [0x1d] == 0x32
    { "FXADDdd", 	OPC_FXADDdd, 	EU_AL_0134, 	OUT_REG_LAT_5F, 	IN_REG_LAT_F }, // [0x1e] == 0x41
    { "FXADDdx", 	OPC_FXADDdx, 	EU_AL_0134, 	OUT_REG_LAT_5F, 	IN_REG_LAT_F }, // [0x1f] == 0x43
    { "FXADDss", 	OPC_FXADDss, 	EU_AL_0134, 	OUT_REG_LAT_5F, 	IN_REG_LAT_F }, // [0x20] == 0x40
    { "FXADDsx", 	OPC_FXADDsx, 	EU_AL_0134, 	OUT_REG_LAT_5F, 	IN_REG_LAT_F }, // [0x21] == 0x42
    { "FXADDxd", 	OPC_FXADDxd, 	EU_AL_0134, 	OUT_REG_LAT_5F, 	IN_REG_LAT_F }, // [0x22] == 0x45
    { "FXADDxs", 	OPC_FXADDxs, 	EU_AL_0134, 	OUT_REG_LAT_5F, 	IN_REG_LAT_F }, // [0x23] == 0x44
    { "FXADDxx", 	OPC_FXADDxx, 	EU_AL_0134, 	OUT_REG_LAT_5F, 	IN_REG_LAT_F }, // [0x24] == 0x47
    { "FXCMPdb", 	OPC_FXCMPdb, 	EU_AL_0134, 	OUT_REG_LAT_PRF, 	IN_REG_LAT_F }, // [0x25] == 0x29
    { "FXCMPsb", 	OPC_FXCMPsb, 	EU_AL_0134, 	OUT_REG_LAT_PRF, 	IN_REG_LAT_F }, // [0x26] == 0x28
    { "FXCMPxb", 	OPC_FXCMPxb, 	EU_AL_0134, 	OUT_REG_LAT_PRF, 	IN_REG_LAT_F }, // [0x27] == 0x2b
    { "FXDIVdd", 	OPC_FXDIVdd, 	EU_AL_25, 		OUT_REG_LAT_14_16F, IN_REG_LAT_F }, // [0x28] == 0x49
    { "FXDIVdx", 	OPC_FXDIVdx, 	EU_AL_25, 		OUT_REG_LAT_11_16F, IN_REG_LAT_F }, // [0x29] == 0x4b
    { "FXDIVss", 	OPC_FXDIVss, 	EU_AL_25, 		OUT_REG_LAT_11_16F, IN_REG_LAT_F }, // [0x2a] == 0x48
    { "FXDIVsx", 	OPC_FXDIVsx, 	EU_AL_25, 		OUT_REG_LAT_11_16F, IN_REG_LAT_F }, // [0x2b] == 0x4a
    { "FXDIVTdd", 	OPC_FXDIVTdd, 	EU_AL_25, 		OUT_REG_LAT_14_16F, IN_REG_LAT_F }, // [0x2c] == 0x61
    { "FXDIVTdx", 	OPC_FXDIVTdx, 	EU_AL_25, 		OUT_REG_LAT_11_16F, IN_REG_LAT_F }, // [0x2d] == 0x63
    { "FXDIVTss", 	OPC_FXDIVTss, 	EU_AL_25, 		OUT_REG_LAT_11_16F, IN_REG_LAT_F }, // [0x2e] == 0x60
    { "FXDIVTsx", 	OPC_FXDIVTsx, 	EU_AL_25, 		OUT_REG_LAT_11_16F, IN_REG_LAT_F }, // [0x2f] == 0x62
    { "FXDIVxd", 	OPC_FXDIVxd, 	EU_AL_25, 		OUT_REG_LAT_14_16F, IN_REG_LAT_F }, // [0x30] == 0x4d
    { "FXDIVxs", 	OPC_FXDIVxs, 	EU_AL_25, 		OUT_REG_LAT_11_16F, IN_REG_LAT_F }, // [0x31] == 0x4c
    { "FXDIVxx", 	OPC_FXDIVxx, 	EU_AL_25, 		OUT_REG_LAT_11_16F, IN_REG_LAT_F }, // [0x32] == 0x4f
    { "FXMULdd", 	OPC_FXMULdd, 	EU_AL_0134, 	OUT_REG_LAT_5F, 	IN_REG_LAT_F }, // [0x33] == 0x51
    { "FXMULdx", 	OPC_FXMULdx, 	EU_AL_0134, 	OUT_REG_LAT_4F, 	IN_REG_LAT_F }, // [0x34] == 0x53
    { "FXMULss", 	OPC_FXMULss, 	EU_AL_0134, 	OUT_REG_LAT_5F, 	IN_REG_LAT_F }, // [0x35] == 0x50
    { "FXMULsx", 	OPC_FXMULsx, 	EU_AL_0134, 	OUT_REG_LAT_4F, 	IN_REG_LAT_F }, // [0x36] == 0x52
    { "FXMULxd", 	OPC_FXMULxd, 	EU_AL_0134, 	OUT_REG_LAT_5F, 	IN_REG_LAT_F }, // [0x37] == 0x55
    { "FXMULxs", 	OPC_FXMULxs, 	EU_AL_0134, 	OUT_REG_LAT_5F, 	IN_REG_LAT_F }, // [0x38] == 0x54
    { "FXMULxx", 	OPC_FXMULxx, 	EU_AL_0134, 	OUT_REG_LAT_4F, 	IN_REG_LAT_F }, // [0x39] == 0x57
    { "FXRSUBdd", 	OPC_FXRSUBdd, 	EU_AL_0134, 	OUT_REG_LAT_5F, 	IN_REG_LAT_F }, // [0x3a] == 0x59
    { "FXRSUBdx", 	OPC_FXRSUBdx, 	EU_AL_0134, 	OUT_REG_LAT_5F, 	IN_REG_LAT_F }, // [0x3b] == 0x5b
    { "FXRSUBss", 	OPC_FXRSUBss, 	EU_AL_0134, 	OUT_REG_LAT_5F, 	IN_REG_LAT_F }, // [0x3c] == 0x58
    { "FXRSUBsx", 	OPC_FXRSUBsx, 	EU_AL_0134, 	OUT_REG_LAT_5F, 	IN_REG_LAT_F }, // [0x3d] == 0x5a
    { "FXSQRTIdx", 	OPC_FXSQRTIdx, 	EU_AL_25, 		OUT_REG_LAT_11F, 	IN_REG_LAT_F }, // [0x3e] == 0x53
    { "FXSQRTIsx", 	OPC_FXSQRTIsx, 	EU_AL_25, 		OUT_REG_LAT_11F, 	IN_REG_LAT_F }, // [0x3f] == 0x52
    { "FXSQRTIxx", 	OPC_FXSQRTIxx, 	EU_AL_25, 		OUT_REG_LAT_11F, 	IN_REG_LAT_F }, // [0x40] == 0x57
    { "FXSQRTTdx", 	OPC_FXSQRTTdx, 	EU_AL_25, 		OUT_REG_LAT_16F, 	IN_REG_LAT_F }, // [0x41] == 0x5f
    { "FXSQRTTsx", 	OPC_FXSQRTTsx, 	EU_AL_25, 		OUT_REG_LAT_16F, 	IN_REG_LAT_F }, // [0x42] == 0x5e
    { "FXSQRTTxx", 	OPC_FXSQRTTxx, 	EU_AL_25, 		OUT_REG_LAT_16F, 	IN_REG_LAT_F }, // [0x43] == 0x5d
    { "FXSQRTUdx", 	OPC_FXSQRTUdx, 	EU_AL_25, 		OUT_REG_LAT_16F, 	IN_REG_LAT_F }, // [0x44] == 0x5b
    { "FXSQRTUsx", 	OPC_FXSQRTUsx, 	EU_AL_25, 		OUT_REG_LAT_16F, 	IN_REG_LAT_F }, // [0x45] == 0x5a
    { "FXSQRTUxx", 	OPC_FXSQRTUxx, 	EU_AL_25, 		OUT_REG_LAT_16F, 	IN_REG_LAT_F }, // [0x46] == 0x59
    { "FXSUBdd", 	OPC_FXSUBdd, 	EU_AL_0134, 	OUT_REG_LAT_5F, 	IN_REG_LAT_F }, // [0x47] == 0x49
    { "FXSUBdx", 	OPC_FXSUBdx, 	EU_AL_0134, 	OUT_REG_LAT_5F, 	IN_REG_LAT_F }, // [0x48] == 0x4b
    { "FXSUBss", 	OPC_FXSUBss, 	EU_AL_0134, 	OUT_REG_LAT_5F, 	IN_REG_LAT_F }, // [0x49] == 0x48
    { "FXSUBsx", 	OPC_FXSUBsx, 	EU_AL_0134, 	OUT_REG_LAT_5F, 	IN_REG_LAT_F }, // [0x4a] == 0x4a
    { "FXSUBxd", 	OPC_FXSUBxd, 	EU_AL_0134, 	OUT_REG_LAT_5F, 	IN_REG_LAT_F }, // [0x4b] == 0x4d
    { "FXSUBxs", 	OPC_FXSUBxs, 	EU_AL_0134, 	OUT_REG_LAT_5F, 	IN_REG_LAT_F }, // [0x4c] == 0x4c
    { "FXSUBxx", 	OPC_FXSUBxx, 	EU_AL_0134, 	OUT_REG_LAT_5F, 	IN_REG_LAT_F }, // [0x4d] == 0x4f
    { "GETFd", 		OPC_GETFd, 		EU_AL_012345, 	OUT_REG_LAT_0I, 	IN_REG_LAT_I }, // [0x4e] == 0x1f
    { "GETFs", 		OPC_GETFs, 		EU_AL_012345, 	OUT_REG_LAT_0I, 	IN_REG_LAT_I }, // [0x4f] == 0x1e
    { "GETPL", 		OPC_GETPL, 		EU_AL_03, 		OUT_REG_LAT_1A, 	IN_REG_LAT_I }, // [0x50] == 0x63
    { "LDB", 		OPC_LDB, 		EU_AL_0235, 	OUT_REG_LAT_2I, 	IN_REG_LAT_I }, // [0x51] == 0x64
    { "LDCSB", 		OPC_LDCSB, 		EU_AL_0235, 	OUT_REG_LAT_2I, 	IN_REG_LAT_I }, // [0x52] == 0x68
    { "LDCSD", 		OPC_LDCSD, 		EU_AL_0235, 	OUT_REG_LAT_2I, 	IN_REG_LAT_I }, // [0x53] == 0x6b
    { "LDCSH", 		OPC_LDCSH, 		EU_AL_0235, 	OUT_REG_LAT_2I, 	IN_REG_LAT_I }, // [0x54] == 0x69
    { "LDCSW", 		OPC_LDCSW, 		EU_AL_0235, 	OUT_REG_LAT_2I, 	IN_REG_LAT_I }, // [0x55] == 0x6a
    { "LDD", 		OPC_LDD, 		EU_AL_0235, 	OUT_REG_LAT_2I, 	IN_REG_LAT_I }, // [0x56] == 0x67
    { "LDDSB", 		OPC_LDDSB, 		EU_AL_0235, 	OUT_REG_LAT_2I, 	IN_REG_LAT_I }, // [0x57] == 0x6c
    { "LDDSD", 		OPC_LDDSD, 		EU_AL_0235, 	OUT_REG_LAT_2I, 	IN_REG_LAT_I }, // [0x58] == 0x6f
    { "LDDSH", 		OPC_LDDSH, 		EU_AL_0235, 	OUT_REG_LAT_2I, 	IN_REG_LAT_I }, // [0x59] == 0x6d
    { "LDDSW", 		OPC_LDDSW, 		EU_AL_0235, 	OUT_REG_LAT_2I, 	IN_REG_LAT_I }, // [0x5a] == 0x6e
    { "LDESB", 		OPC_LDESB, 		EU_AL_0235, 	OUT_REG_LAT_2I, 	IN_REG_LAT_I }, // [0x5b] == 0x70
    { "LDESD", 		OPC_LDESD, 		EU_AL_0235, 	OUT_REG_LAT_2I, 	IN_REG_LAT_I }, // [0x5c] == 0x73
    { "LDESH", 		OPC_LDESH, 		EU_AL_0235, 	OUT_REG_LAT_2I, 	IN_REG_LAT_I }, // [0x5d] == 0x71
    { "LDESW", 		OPC_LDESW, 		EU_AL_0235, 	OUT_REG_LAT_2I, 	IN_REG_LAT_I }, // [0x5e] == 0x72
    { "LDFSB", 		OPC_LDFSB, 		EU_AL_0235, 	OUT_REG_LAT_2I, 	IN_REG_LAT_I }, // [0x5f] == 0x74
    { "LDFSD", 		OPC_LDFSD, 		EU_AL_0235, 	OUT_REG_LAT_2I, 	IN_REG_LAT_I }, // [0x60] == 0x77
    { "LDFSH", 		OPC_LDFSH, 		EU_AL_0235, 	OUT_REG_LAT_2I, 	IN_REG_LAT_I }, // [0x61] == 0x75
    { "LDFSW", 		OPC_LDFSW, 		EU_AL_0235, 	OUT_REG_LAT_2I, 	IN_REG_LAT_I }, // [0x62] == 0x76
    { "LDGSB", 		OPC_LDGSB, 		EU_AL_0235, 	OUT_REG_LAT_2I, 	IN_REG_LAT_I }, // [0x63] == 0x78
    { "LDGSD", 		OPC_LDGSD, 		EU_AL_0235, 	OUT_REG_LAT_2I, 	IN_REG_LAT_I }, // [0x64] == 0x7b
    { "LDGSH", 		OPC_LDGSH, 		EU_AL_0235, 	OUT_REG_LAT_2I, 	IN_REG_LAT_I }, // [0x65] == 0x79
    { "LDGSW", 		OPC_LDGSW, 		EU_AL_0235, 	OUT_REG_LAT_2I, 	IN_REG_LAT_I }, // [0x66] == 0x7a
    { "LDH", 		OPC_LDH, 		EU_AL_0235, 	OUT_REG_LAT_2I, 	IN_REG_LAT_I }, // [0x67] == 0x65
    { "LDSSB", 		OPC_LDSSB, 		EU_AL_0235, 	OUT_REG_LAT_2I, 	IN_REG_LAT_I }, // [0x68] == 0x7c
    { "LDSSD", 		OPC_LDSSD, 		EU_AL_0235, 	OUT_REG_LAT_2I, 	IN_REG_LAT_I }, // [0x69] == 0x7f
    { "LDSSH", 		OPC_LDSSH, 		EU_AL_0235, 	OUT_REG_LAT_2I, 	IN_REG_LAT_I }, // [0x6a] == 0x7d
    { "LDSSW", 		OPC_LDSSW, 		EU_AL_0235, 	OUT_REG_LAT_2I, 	IN_REG_LAT_I }, // [0x6b] == 0x7e
    { "LDW", 		OPC_LDW, 		EU_AL_0235, 	OUT_REG_LAT_2I, 	IN_REG_LAT_I }, // [0x6c] == 0x66
    { "LZCNTd", 	OPC_LZCNTd, 	EU_AL_14, 		OUT_REG_LAT_0I, 	IN_REG_LAT_I }, // [0x6d] == 0x65
    { "LZCNTs", 	OPC_LZCNTs, 	EU_AL_14, 		OUT_REG_LAT_0I, 	IN_REG_LAT_I }, // [0x6e] == 0x64
    { "MERGEd", 	OPC_MERGEd, 	EU_AL_012345, 	OUT_REG_LAT_0I, 	IN_REG_LAT_I }, // [0x6f] == 0xf
    { "MERGEs", 	OPC_MERGEs, 	EU_AL_012345, 	OUT_REG_LAT_0I, 	IN_REG_LAT_I }, // [0x70] == 0xe
    { "MOVFI", 		OPC_MOVFI, 		EU_AL_0134, 	OUT_REG_LAT_4F, 	IN_REG_LAT_F }, // [0x71] == 0x5c
    { "MOVIF", 		OPC_MOVIF, 		EU_AL_0134, 	OUT_REG_LAT_4F, 	IN_REG_LAT_F }, // [0x72] == 0x5e
    { "MOVTd", 		OPC_MOVTd, 		EU_AL_0, 		OUT_REG_LAT_1A, 	IN_REG_LAT_I }, // [0x73] == 0x61
    { "MOVTs", 		OPC_MOVTs, 		EU_AL_0, 		OUT_REG_LAT_1A, 	IN_REG_LAT_I }, // [0x74] == 0x60
    { "MOVX", 		OPC_MOVX, 		EU_AL_012345, 	OUT_REG_LAT_4F, 	IN_REG_LAT_F }, // [0x75] == 0x5f
    { "ORd", 		OPC_ORd, 		EU_AL_012345, 	OUT_REG_LAT_0I, 	IN_REG_LAT_I }, // [0x76] == 0x5
    { "ORNd", 		OPC_ORNd, 		EU_AL_012345, 	OUT_REG_LAT_0I, 	IN_REG_LAT_I }, // [0x77] == 0x7
    { "ORNs", 		OPC_ORNs, 		EU_AL_012345, 	OUT_REG_LAT_0I, 	IN_REG_LAT_I }, // [0x78] == 0x6
    { "ORs", 		OPC_ORs, 		EU_AL_012345, 	OUT_REG_LAT_0I, 	IN_REG_LAT_I }, // [0x79] == 0x4
    { "POPCNTd", 	OPC_POPCNTd, 	EU_AL_14, 		OUT_REG_LAT_0I, 	IN_REG_LAT_I }, // [0x7a] == 0x67
    { "POPCNTs", 	OPC_POPCNTs, 	EU_AL_14, 		OUT_REG_LAT_0I, 	IN_REG_LAT_I }, // [0x7b] == 0x66
    { "SARd", 		OPC_SARd, 		EU_AL_012345, 	OUT_REG_LAT_0I, 	IN_REG_LAT_I }, // [0x7c] == 0x1d
    { "SARs", 		OPC_SARs, 		EU_AL_012345, 	OUT_REG_LAT_0I, 	IN_REG_LAT_I }, // [0x7d] == 0x1c
    { "SCLd", 		OPC_SCLd, 		EU_AL_012345, 	OUT_REG_LAT_0I, 	IN_REG_LAT_I }, // [0x7e] == 0x15
    { "SCLs", 		OPC_SCLs, 		EU_AL_012345, 	OUT_REG_LAT_0I, 	IN_REG_LAT_I }, // [0x7f] == 0x14
    { "SCRd", 		OPC_SCRd, 		EU_AL_012345, 	OUT_REG_LAT_0I, 	IN_REG_LAT_I }, // [0x80] == 0x17
    { "SCRs", 		OPC_SCRs, 		EU_AL_012345, 	OUT_REG_LAT_0I, 	IN_REG_LAT_I }, // [0x81] == 0x16
    { "SDIVd", 		OPC_SDIVd, 		EU_AL_5, 		OUT_REG_LAT_11_18F, IN_REG_LAT_I }, // [0x82] == 0x43
    { "SDIVs", 		OPC_SDIVs, 		EU_AL_5, 		OUT_REG_LAT_11_14F, IN_REG_LAT_I }, // [0x83] == 0x42
    { "SDIVX", 		OPC_SDIVX, 		EU_AL_5, 		OUT_REG_LAT_11_14F, IN_REG_LAT_I }, // [0x84] == 0x46
    { "SHLd", 		OPC_SHLd, 		EU_AL_012345, 	OUT_REG_LAT_0I, 	IN_REG_LAT_I }, // [0x85] == 0x19
    { "SHLs", 		OPC_SHLs, 		EU_AL_012345, 	OUT_REG_LAT_0I, 	IN_REG_LAT_I }, // [0x86] == 0x18
    { "SHRd", 		OPC_SHRd, 		EU_AL_012345, 	OUT_REG_LAT_0I, 	IN_REG_LAT_I }, // [0x87] == 0x1b
    { "SHRs", 		OPC_SHRs, 		EU_AL_012345, 	OUT_REG_LAT_0I, 	IN_REG_LAT_I }, // [0x88] == 0x1a
    { "SMODX", 		OPC_SMODX, 		EU_AL_5, 		OUT_REG_LAT_10_14F, IN_REG_LAT_F }, // [0x89] == 0x47
    { "STB", 		OPC_STB, 		EU_AL_25, 		OUT_REG_LAT_LAST, 	IN_REG_LAT_S }, // [0x8a] == 0x24
    { "STCSB", 		OPC_STCSB, 		EU_AL_25, 		OUT_REG_LAT_LAST, 	IN_REG_LAT_S }, // [0x8b] == 0x28
    { "STCSD", 		OPC_STCSD, 		EU_AL_25, 		OUT_REG_LAT_LAST, 	IN_REG_LAT_S }, // [0x8c] == 0x2b
    { "STCSH", 		OPC_STCSH, 		EU_AL_25, 		OUT_REG_LAT_LAST, 	IN_REG_LAT_S }, // [0x8d] == 0x29
    { "STCSW", 		OPC_STCSW, 		EU_AL_25, 		OUT_REG_LAT_LAST, 	IN_REG_LAT_S }, // [0x8e] == 0x2a
    { "STD", 		OPC_STD, 		EU_AL_25, 		OUT_REG_LAT_LAST, 	IN_REG_LAT_S }, // [0x8f] == 0x27
    { "STDSB", 		OPC_STDSB, 		EU_AL_25, 		OUT_REG_LAT_LAST, 	IN_REG_LAT_S }, // [0x90] == 0x2c
    { "STDSD", 		OPC_STDSD, 		EU_AL_25, 		OUT_REG_LAT_LAST, 	IN_REG_LAT_S }, // [0x91] == 0x2f
    { "STDSH", 		OPC_STDSH, 		EU_AL_25, 		OUT_REG_LAT_LAST, 	IN_REG_LAT_S }, // [0x92] == 0x2d
    { "STDSW", 		OPC_STDSW, 		EU_AL_25, 		OUT_REG_LAT_LAST, 	IN_REG_LAT_S }, // [0x93] == 0x2e
    { "STESB", 		OPC_STESB, 		EU_AL_25, 		OUT_REG_LAT_LAST, 	IN_REG_LAT_S }, // [0x94] == 0x30
    { "STESD", 		OPC_STESD, 		EU_AL_25, 		OUT_REG_LAT_LAST, 	IN_REG_LAT_S }, // [0x95] == 0x33
    { "STESH", 		OPC_STESH, 		EU_AL_25, 		OUT_REG_LAT_LAST, 	IN_REG_LAT_S }, // [0x96] == 0x31
    { "STESW", 		OPC_STESW, 		EU_AL_25, 		OUT_REG_LAT_LAST, 	IN_REG_LAT_S }, // [0x97] == 0x32
    { "STFSB", 		OPC_STFSB, 		EU_AL_25, 		OUT_REG_LAT_LAST, 	IN_REG_LAT_S }, // [0x98] == 0x34
    { "STFSD", 		OPC_STFSD, 		EU_AL_25, 		OUT_REG_LAT_LAST, 	IN_REG_LAT_S }, // [0x99] == 0x37
    { "STFSH", 		OPC_STFSH, 		EU_AL_25, 		OUT_REG_LAT_LAST, 	IN_REG_LAT_S }, // [0x9a] == 0x35
    { "STFSW", 		OPC_STFSW, 		EU_AL_25, 		OUT_REG_LAT_LAST, 	IN_REG_LAT_S }, // [0x9b] == 0x36
    { "STGSB", 		OPC_STGSB, 		EU_AL_25, 		OUT_REG_LAT_LAST, 	IN_REG_LAT_S }, // [0x9c] == 0x38
    { "STGSD", 		OPC_STGSD, 		EU_AL_25, 		OUT_REG_LAT_LAST, 	IN_REG_LAT_S }, // [0x9d] == 0x3b
    { "STGSH", 		OPC_STGSH, 		EU_AL_25, 		OUT_REG_LAT_LAST, 	IN_REG_LAT_S }, // [0x9e] == 0x39
    { "STGSW", 		OPC_STGSW, 		EU_AL_25, 		OUT_REG_LAT_LAST, 	IN_REG_LAT_S }, // [0x9f] == 0x3a
    { "STH", 		OPC_STH, 		EU_AL_25, 		OUT_REG_LAT_LAST, 	IN_REG_LAT_S }, // [0xa0] == 0x25
    { "STSSB", 		OPC_STSSB, 		EU_AL_25, 		OUT_REG_LAT_LAST, 	IN_REG_LAT_S }, // [0xa1] == 0x3c
    { "STSSD", 		OPC_STSSD, 		EU_AL_25, 		OUT_REG_LAT_LAST, 	IN_REG_LAT_S }, // [0xa2] == 0x3f
    { "STSSH", 		OPC_STSSH, 		EU_AL_25, 		OUT_REG_LAT_LAST, 	IN_REG_LAT_S }, // [0xa3] == 0x3d
    { "STSSW", 		OPC_STSSW, 		EU_AL_25, 		OUT_REG_LAT_LAST, 	IN_REG_LAT_S }, // [0xa4] == 0x3e
    { "STW", 		OPC_STW, 		EU_AL_25, 		OUT_REG_LAT_LAST, 	IN_REG_LAT_S }, // [0xa5] == 0x26
    { "SUBd", 		OPC_SUBd, 		EU_AL_012345, 	OUT_REG_LAT_0I, 	IN_REG_LAT_I }, // [0xa6] == 0x13
    { "SUBs", 		OPC_SUBs, 		EU_AL_012345, 	OUT_REG_LAT_0I, 	IN_REG_LAT_I }, // [0xa7] == 0x12
    { "SXT", 		OPC_SXT, 		EU_AL_012345, 	OUT_REG_LAT_0I, 	IN_REG_LAT_I }, // [0xa8] == 0xc
    { "UDIVd", 		OPC_UDIVd, 		EU_AL_5, 		OUT_REG_LAT_11_18F, IN_REG_LAT_F }, // [0xa9] == 0x41
    { "UDIVs", 		OPC_UDIVs, 		EU_AL_5, 		OUT_REG_LAT_11_14F, IN_REG_LAT_F }, // [0xaa] == 0x40
    { "UDIVX", 		OPC_UDIVX, 		EU_AL_5, 		OUT_REG_LAT_11_14F, IN_REG_LAT_F }, // [0xab] == 0x44
    { "UMODX", 		OPC_UMODX, 		EU_AL_5, 		OUT_REG_LAT_10_14F, IN_REG_LAT_F }, // [0xac] == 0x45
    { "VFSI", 		OPC_VFSI, 		EU_AL_14, 		OUT_REG_LAT_LAST, 	IN_REG_LAT_LAST }, // [0xad] == 0x63
    { "XORd", 		OPC_XORd, 		EU_AL_012345, 	OUT_REG_LAT_0I, 	IN_REG_LAT_I }, // [0xae] == 0x9
    { "XORNd", 		OPC_XORNd, 		EU_AL_012345, 	OUT_REG_LAT_0I, 	IN_REG_LAT_I }, // [0xaf] == 0xb
    { "XORNs", 		OPC_XORNs, 		EU_AL_012345, 	OUT_REG_LAT_0I, 	IN_REG_LAT_I }, // [0xb0] == 0xa
    { "XORs", 		OPC_XORs, 		EU_AL_012345, 	OUT_REG_LAT_0I, 	IN_REG_LAT_I }, // [0xb1] == 0x8
    { "NONE", 		OPC_NONE, 		EU_AL_012345, 	OUT_REG_LAT_0I, 	IN_REG_LAT_I }, // [0xb2] == 0xc0

 		 		/// операции с длинной кодировкой
    { "APTOAP", 	OPL_APTOAP, 	EU_AL_0134, 	OUT_REG_LAT_1A, 	IN_REG_LAT_LAST }, // [0xb3] == 0x50
    { "APTOAPB", 	OPL_APTOAPB, 	EU_AL_0134, 	OUT_REG_LAT_1A, 	IN_REG_LAT_LAST }, // [0xb4] == 0x51
    { "CAST", 		OPL_CAST, 		EU_AL_0134, 	OUT_REG_LAT_1A, 	IN_REG_LAT_LAST }, // [0xb5] == 0x55
    { "FCMPd", 		OPL_FCMPd, 		EU_AL_0134, 	OUT_REG_LAT_2M, 	IN_REG_LAT_F }, // [0xb6] == 0x2d
    { "FCMPdf", 	OPL_FCMPdf, 	EU_AL_0134, 	OUT_REG_LAT_2M, 	IN_REG_LAT_F }, // [0xb7] == 0x2f
    { "FCMPs", 		OPL_FCMPs, 		EU_AL_0134, 	OUT_REG_LAT_2M, 	IN_REG_LAT_F }, // [0xb8] == 0x2c
    { "FCMPsf", 	OPL_FCMPsf, 	EU_AL_0134, 	OUT_REG_LAT_2M, 	IN_REG_LAT_F }, // [0xb9] == 0x2e
    { "FDIVd", 		OPL_FDIVd, 		EU_AL_5, 		OUT_REG_LAT_14F, 	IN_REG_LAT_F }, // [0xba] == 0x49
    { "FDIVs", 		OPL_FDIVs, 		EU_AL_5, 		OUT_REG_LAT_11F, 	IN_REG_LAT_F }, // [0xbb] == 0x48
    { "FRCPs", 		OPL_FRCPs, 		EU_AL_5, 		OUT_REG_LAT_6F, 	IN_REG_LAT_F }, // [0xbc] == 0x50
    { "FRSQRTs", 	OPL_FRSQRTs, 	EU_AL_5, 		OUT_REG_LAT_6F, 	IN_REG_LAT_F }, // [0xbd] == 0x54
    { "FSQRTId", 	OPL_FSQRTId, 	EU_AL_5, 		OUT_REG_LAT_11F, 	IN_REG_LAT_F }, // [0xbe] == 0x4d
    { "FSQRTs", 	OPL_FSQRTs, 	EU_AL_5, 		OUT_REG_LAT_10F, 	IN_REG_LAT_F }, // [0xbf] == 0x4c
    { "FSQRTTd", 	OPL_FSQRTTd, 	EU_AL_5, 		OUT_REG_LAT_14F, 	IN_REG_LAT_F }, // [0xc0] == 0x51
    { "FXCMPdf", 	OPL_FXCMPdf, 	EU_AL_0134, 	OUT_REG_LAT_4F, 	IN_REG_LAT_F }, // [0xc1] == 0x29
    { "FXCMPsf", 	OPL_FXCMPsf, 	EU_AL_0134, 	OUT_REG_LAT_4F, 	IN_REG_LAT_F }, // [0xc2] == 0x28
    { "FXCMPxf", 	OPL_FXCMPxf, 	EU_AL_0134, 	OUT_REG_LAT_4F, 	IN_REG_LAT_F }, // [0xc3] == 0x2b
    { "GETSOD", 	OPL_GETSOD, 	EU_AL_0134, 	OUT_REG_LAT_1A, 	IN_REG_LAT_F }, // [0xc4] == 0x5a
    { "GETSP", 		OPL_GETSP, 		EU_AL_0, 		OUT_REG_LAT_1A, 	IN_REG_LAT_I }, // [0xc5] == 0x58
    { "GETTAGd", 	OPL_GETTAGd, 	EU_AL_25, 		OUT_REG_LAT_0I, 	IN_REG_LAT_I }, // [0xc6] == 0x9
    { "GETTAGs", 	OPL_GETTAGs, 	EU_AL_25, 		OUT_REG_LAT_0I, 	IN_REG_LAT_I }, // [0xc7] == 0x8
    { "GETTC", 		OPL_GETTC, 		EU_AL_03, 		OUT_REG_LAT_LAST, 	IN_REG_LAT_LAST }, // [0xc8] == 0x24
    { "GETTD", 		OPL_GETTD, 		EU_AL_03, 		OUT_REG_LAT_1A, 	IN_REG_LAT_I }, // [0xc9] == 0x56
    { "GETVA", 		OPL_GETVA, 		EU_AL_03, 		OUT_REG_LAT_1A, 	IN_REG_LAT_I }, // [0xca] == 0x52
    { "INVTC", 		OPL_INVTC, 		EU_AL_03, 		OUT_REG_LAT_LAST, 	IN_REG_LAT_LAST }, // [0xcb] == 0x26
    { "LDAAB", 		OPL_LDAAB, 		EU_AL_25, 		OUT_REG_LAT_8R, 	IN_REG_LAT_I }, // [0xcc] == 0x5c
    { "LDAAD", 		OPL_LDAAD, 		EU_AL_25, 		OUT_REG_LAT_8R, 	IN_REG_LAT_I }, // [0xcd] == 0x5f
    { "LDAAH", 		OPL_LDAAH, 		EU_AL_25, 		OUT_REG_LAT_8R, 	IN_REG_LAT_I }, // [0xce] == 0x5d
    { "LDAAQ", 		OPL_LDAAQ, 		EU_AL_25, 		OUT_REG_LAT_8R, 	IN_REG_LAT_I }, // [0xcf] == 0x7f
    { "LDAAW", 		OPL_LDAAW, 		EU_AL_25, 		OUT_REG_LAT_8R, 	IN_REG_LAT_I }, // [0xd0] == 0x5e
    { "LDAPB", 		OPL_LDAPB, 		EU_AL_0235, 	OUT_REG_LAT_2I, 	IN_REG_LAT_I }, // [0xd1] == 0x68
    { "LDAPD", 		OPL_LDAPD, 		EU_AL_0235, 	OUT_REG_LAT_2I, 	IN_REG_LAT_I }, // [0xd2] == 0x6b
    { "LDAPH", 		OPL_LDAPH, 		EU_AL_0235, 	OUT_REG_LAT_2I, 	IN_REG_LAT_I }, // [0xd3] == 0x69
    { "LDAPQ", 		OPL_LDAPQ, 		EU_AL_0235, 	OUT_REG_LAT_2I, 	IN_REG_LAT_I }, // [0xd4] == 0x7a
    { "LDAPW", 		OPL_LDAPW, 		EU_AL_0235, 	OUT_REG_LAT_2I, 	IN_REG_LAT_I }, // [0xd5] == 0x6a
    { "LDCSQ", 		OPL_LDCSQ, 		EU_AL_0235, 	OUT_REG_LAT_2I, 	IN_REG_LAT_I }, // [0xd6] == 0x42
    { "LDCUDB", 	OPL_LDCUDB, 	EU_AL_0235, 	OUT_REG_LAT_2I, 	IN_REG_LAT_I }, // [0xd7] == 0x60
    { "LDCUDD", 	OPL_LDCUDD, 	EU_AL_0235, 	OUT_REG_LAT_2I, 	IN_REG_LAT_I }, // [0xd8] == 0x63
    { "LDCUDH", 	OPL_LDCUDH, 	EU_AL_0235, 	OUT_REG_LAT_2I, 	IN_REG_LAT_I }, // [0xd9] == 0x61
    { "LDCUDQ", 	OPL_LDCUDQ, 	EU_AL_0235, 	OUT_REG_LAT_2I, 	IN_REG_LAT_I }, // [0xda] == 0x78
    { "LDCUDW", 	OPL_LDCUDW, 	EU_AL_0235, 	OUT_REG_LAT_2I, 	IN_REG_LAT_I }, // [0xdb] == 0x62
    { "LDDSQ", 		OPL_LDDSQ, 		EU_AL_0235, 	OUT_REG_LAT_2I, 	IN_REG_LAT_I }, // [0xdc] == 0x43
    { "LDESQ", 		OPL_LDESQ, 		EU_AL_0235, 	OUT_REG_LAT_2I, 	IN_REG_LAT_I }, // [0xdd] == 0x44
    { "LDFSQ", 		OPL_LDFSQ, 		EU_AL_0235, 	OUT_REG_LAT_2I, 	IN_REG_LAT_I }, // [0xde] == 0x45
    { "LDGDB", 		OPL_LDGDB, 		EU_AL_0235, 	OUT_REG_LAT_2I, 	IN_REG_LAT_I }, // [0xdf] == 0x64
    { "LDGDD", 		OPL_LDGDD, 		EU_AL_0235, 	OUT_REG_LAT_2I, 	IN_REG_LAT_I }, // [0xe0] == 0x67
    { "LDGDH", 		OPL_LDGDH, 		EU_AL_0235, 	OUT_REG_LAT_2I, 	IN_REG_LAT_I }, // [0xe1] == 0x65
    { "LDGDQ", 		OPL_LDGDQ, 		EU_AL_0235, 	OUT_REG_LAT_2I, 	IN_REG_LAT_I }, // [0xe2] == 0x79
    { "LDGDW", 		OPL_LDGDW, 		EU_AL_0235, 	OUT_REG_LAT_2I, 	IN_REG_LAT_I }, // [0xe3] == 0x66
    { "LDGSQ", 		OPL_LDGSQ, 		EU_AL_0235, 	OUT_REG_LAT_2I, 	IN_REG_LAT_I }, // [0xe4] == 0x46
    { "LDODPB", 	OPL_LDODPB, 	EU_AL_0235, 	OUT_REG_LAT_2I, 	IN_REG_LAT_I }, // [0xe5] == 0x74
    { "LDODPD", 	OPL_LDODPD, 	EU_AL_0235, 	OUT_REG_LAT_2I, 	IN_REG_LAT_I }, // [0xe6] == 0x77
    { "LDODPH", 	OPL_LDODPH, 	EU_AL_0235, 	OUT_REG_LAT_2I, 	IN_REG_LAT_I }, // [0xe7] == 0x75
    { "LDODPQ", 	OPL_LDODPQ, 	EU_AL_0235, 	OUT_REG_LAT_2I, 	IN_REG_LAT_I }, // [0xe8] == 0x7d
    { "LDODPW", 	OPL_LDODPW, 	EU_AL_0235, 	OUT_REG_LAT_2I, 	IN_REG_LAT_I }, // [0xe9] == 0x76
    { "LDODRB", 	OPL_LDODRB, 	EU_AL_0235, 	OUT_REG_LAT_2I, 	IN_REG_LAT_I }, // [0xea] == 0x6c
    { "LDODRD", 	OPL_LDODRD, 	EU_AL_0235, 	OUT_REG_LAT_2I, 	IN_REG_LAT_I }, // [0xeb] == 0x6f
    { "LDODRH", 	OPL_LDODRH, 	EU_AL_0235, 	OUT_REG_LAT_2I, 	IN_REG_LAT_I }, // [0xec] == 0x6d
    { "LDODRQ", 	OPL_LDODRQ, 	EU_AL_0235, 	OUT_REG_LAT_2I, 	IN_REG_LAT_I }, // [0xed] == 0x7b
    { "LDODRW", 	OPL_LDODRW, 	EU_AL_0235, 	OUT_REG_LAT_2I, 	IN_REG_LAT_I }, // [0xee] == 0x6e
    { "LDODWB", 	OPL_LDODWB, 	EU_AL_0235, 	OUT_REG_LAT_2I, 	IN_REG_LAT_I }, // [0xef] == 0x70
    { "LDODWD", 	OPL_LDODWD, 	EU_AL_0235, 	OUT_REG_LAT_2I, 	IN_REG_LAT_I }, // [0xf0] == 0x73
    { "LDODWH", 	OPL_LDODWH, 	EU_AL_0235, 	OUT_REG_LAT_2I, 	IN_REG_LAT_I }, // [0xf1] == 0x71
    { "LDODWQ", 	OPL_LDODWQ, 	EU_AL_0235, 	OUT_REG_LAT_2I, 	IN_REG_LAT_I }, // [0xf2] == 0x7c
    { "LDODWW", 	OPL_LDODWW, 	EU_AL_0235, 	OUT_REG_LAT_2I, 	IN_REG_LAT_I }, // [0xf3] == 0x72
    { "LDRD", 		OPL_LDRD, 		EU_AL_0235, 	OUT_REG_LAT_2I, 	IN_REG_LAT_I }, // [0xf4] == 0x5b
    { "LDSSQ", 		OPL_LDSSQ, 		EU_AL_0235, 	OUT_REG_LAT_2I, 	IN_REG_LAT_I }, // [0xf5] == 0x47
    { "MOVTq", 		OPL_MOVTq, 		EU_AL_0134, 	OUT_REG_LAT_1A, 	IN_REG_LAT_I }, // [0xf6] == 0x57
    { "MULd", 		OPL_MULd, 		EU_AL_03, 		OUT_REG_LAT_4F, 	IN_REG_LAT_F }, // [0xf7] == 0x21
    { "MULs", 		OPL_MULs, 		EU_AL_03, 		OUT_REG_LAT_4F, 	IN_REG_LAT_F }, // [0xf8] == 0x20
    { "ODTOAP", 	OPL_ODTOAP, 	EU_AL_0134, 	OUT_REG_LAT_1A, 	IN_REG_LAT_F }, // [0xf9] == 0x54
    { "PACKSSHB", 	OPL_PACKSSHB, 	EU_AL_14, 		OUT_REG_LAT_1M, 	IN_REG_LAT_F }, // [0xfa] == 0x8
    { "PACKSSWH", 	OPL_PACKSSWH, 	EU_AL_14, 		OUT_REG_LAT_1M, 	IN_REG_LAT_F }, // [0xfb] == 0xa
    { "PACKUSHB", 	OPL_PACKUSHB, 	EU_AL_14, 		OUT_REG_LAT_1M, 	IN_REG_LAT_F }, // [0xfc] == 0x9
    { "PADDB", 		OPL_PADDB, 		EU_AL_03, 		OUT_REG_LAT_1M, 	IN_REG_LAT_F }, // [0xfd] == 0x8
    { "PADDD", 		OPL_PADDD, 		EU_AL_03, 		OUT_REG_LAT_1M, 	IN_REG_LAT_F }, // [0xfe] == 0xf
    { "PADDH", 		OPL_PADDH, 		EU_AL_03, 		OUT_REG_LAT_1M, 	IN_REG_LAT_F }, // [0xff] == 0x9
    { "PADDSB", 	OPL_PADDSB, 	EU_AL_03, 		OUT_REG_LAT_1M, 	IN_REG_LAT_F }, // [0x100] == 0xa
    { "PADDSH", 	OPL_PADDSH, 	EU_AL_03, 		OUT_REG_LAT_1M, 	IN_REG_LAT_F }, // [0x101] == 0xb
    { "PADDUSB", 	OPL_PADDUSB, 	EU_AL_03, 		OUT_REG_LAT_1M, 	IN_REG_LAT_F }, // [0x102] == 0xc
    { "PADDUSH", 	OPL_PADDUSH, 	EU_AL_03, 		OUT_REG_LAT_1M, 	IN_REG_LAT_F }, // [0x103] == 0xd
    { "PADDW", 		OPL_PADDW, 		EU_AL_03, 		OUT_REG_LAT_1M, 	IN_REG_LAT_F }, // [0x104] == 0xe
    { "PANDd", 		OPL_PANDd, 		EU_AL_0134, 	OUT_REG_LAT_LAST, 	IN_REG_LAT_F }, // [0x105] == 0x48
    { "PANDNd", 	OPL_PANDNd, 	EU_AL_0134, 	OUT_REG_LAT_LAST, 	IN_REG_LAT_F }, // [0x106] == 0x49
    { "PAVGUSB", 	OPL_PAVGUSB, 	EU_AL_03, 		OUT_REG_LAT_1M, 	IN_REG_LAT_F }, // [0x107] == 0x1e
    { "PAVGUSH", 	OPL_PAVGUSH, 	EU_AL_03, 		OUT_REG_LAT_1M, 	IN_REG_LAT_F }, // [0x108] == 0x1f
    { "PCMPEQB", 	OPL_PCMPEQB, 	EU_AL_03, 		OUT_REG_LAT_1M, 	IN_REG_LAT_F }, // [0x109] == 0x18
    { "PCMPEQH", 	OPL_PCMPEQH, 	EU_AL_03, 		OUT_REG_LAT_1M, 	IN_REG_LAT_F }, // [0x10a] == 0x19
    { "PCMPEQW", 	OPL_PCMPEQW, 	EU_AL_03, 		OUT_REG_LAT_1M, 	IN_REG_LAT_F }, // [0x10b] == 0x1a
    { "PCMPGTB", 	OPL_PCMPGTB, 	EU_AL_03, 		OUT_REG_LAT_1M, 	IN_REG_LAT_F }, // [0x10c] == 0x1b
    { "PCMPGTH", 	OPL_PCMPGTH, 	EU_AL_03, 		OUT_REG_LAT_1M, 	IN_REG_LAT_F }, // [0x10d] == 0x1c
    { "PCMPGTW", 	OPL_PCMPGTW, 	EU_AL_03, 		OUT_REG_LAT_1M, 	IN_REG_LAT_F }, // [0x10e] == 0x1d
    { "PEXTRH", 	OPL_PEXTRH, 	EU_AL_14, 		OUT_REG_LAT_1M, 	IN_REG_LAT_F }, // [0x10f] == 0x1e
    { "PFADDd", 	OPL_PFADDd, 	EU_AL_0134, 	OUT_REG_LAT_4F, 	IN_REG_LAT_F }, // [0x110] == 0x31
    { "PFADDs", 	OPL_PFADDs, 	EU_AL_0134, 	OUT_REG_LAT_4F, 	IN_REG_LAT_F }, // [0x111] == 0x30
    { "PFCMPd", 	OPL_PFCMPd, 	EU_AL_0134, 	OUT_REG_LAT_2M, 	IN_REG_LAT_F }, // [0x112] == 0x3b
    { "PFCMPs", 	OPL_PFCMPs, 	EU_AL_0134, 	OUT_REG_LAT_2M, 	IN_REG_LAT_F }, // [0x113] == 0x3a
    { "PFDIVd", 	OPL_PFDIVd, 	EU_AL_25, 		OUT_REG_LAT_14F, 	IN_REG_LAT_F }, // [0x114] == 0x4b
    { "PFDIVs", 	OPL_PFDIVs, 	EU_AL_25, 		OUT_REG_LAT_11F, 	IN_REG_LAT_F }, // [0x115] == 0x4a
    { "PFMAXd", 	OPL_PFMAXd, 	EU_AL_0134, 	OUT_REG_LAT_2M, 	IN_REG_LAT_F }, // [0x116] == 0x37
    { "PFMAXs", 	OPL_PFMAXs, 	EU_AL_0134, 	OUT_REG_LAT_2M, 	IN_REG_LAT_F }, // [0x117] == 0x36
    { "PFMINd", 	OPL_PFMINd, 	EU_AL_0134, 	OUT_REG_LAT_2M, 	IN_REG_LAT_F }, // [0x118] == 0x35
    { "PFMINs", 	OPL_PFMINs, 	EU_AL_0134, 	OUT_REG_LAT_2M, 	IN_REG_LAT_F }, // [0x119] == 0x34
    { "PFMULd", 	OPL_PFMULd, 	EU_AL_0134, 	OUT_REG_LAT_4F, 	IN_REG_LAT_F }, // [0x11a] == 0x39
    { "PFMULs", 	OPL_PFMULs, 	EU_AL_0134, 	OUT_REG_LAT_4F, 	IN_REG_LAT_F }, // [0x11b] == 0x38
    { "PFSQRTs", 	OPL_PFSQRTs, 	EU_AL_25, 		OUT_REG_LAT_10F, 	IN_REG_LAT_F }, // [0x11c] == 0x4e
    { "PFSQRTTd", 	OPL_PFSQRTTd, 	EU_AL_25, 		OUT_REG_LAT_14F, 	IN_REG_LAT_F }, // [0x11d] == 0x53
    { "PFSUBd", 	OPL_PFSUBd, 	EU_AL_0134, 	OUT_REG_LAT_4F, 	IN_REG_LAT_F }, // [0x11e] == 0x33
    { "PFSUBs", 	OPL_PFSUBs, 	EU_AL_0134, 	OUT_REG_LAT_4F, 	IN_REG_LAT_F }, // [0x11f] == 0x32
    { "PINSH", 		OPL_PINSH, 		EU_AL_14, 		OUT_REG_LAT_1M, 	IN_REG_LAT_F }, // [0x120] == 0x1f
    { "PMADDH", 	OPL_PMADDH, 	EU_AL_14, 		OUT_REG_LAT_2M, 	IN_REG_LAT_F }, // [0x121] == 0x1a
    { "PMAXSH", 	OPL_PMAXSH, 	EU_AL_03, 		OUT_REG_LAT_1M, 	IN_REG_LAT_F }, // [0x122] == 0x3
    { "PMAXUB", 	OPL_PMAXUB, 	EU_AL_03, 		OUT_REG_LAT_1M, 	IN_REG_LAT_F }, // [0x123] == 0x2
    { "PMINSH", 	OPL_PMINSH, 	EU_AL_03, 		OUT_REG_LAT_1M, 	IN_REG_LAT_F }, // [0x124] == 0x1
    { "PMINUB", 	OPL_PMINUB, 	EU_AL_03, 		OUT_REG_LAT_1M, 	IN_REG_LAT_F }, // [0x125] == 0x0
    { "PMOVMSKB", 	OPL_PMOVMSKB, 	EU_AL_14, 		OUT_REG_LAT_1M, 	IN_REG_LAT_F }, // [0x126] == 0xb
    { "PMOVMSKPD", 	OPL_PMOVMSKPD, 	EU_AL_14, 		OUT_REG_LAT_1M, 	IN_REG_LAT_F }, // [0x127] == 0x7
    { "PMOVMSKPS", 	OPL_PMOVMSKPS, 	EU_AL_14, 		OUT_REG_LAT_1M, 	IN_REG_LAT_F }, // [0x128] == 0x6
    { "PMULHH", 	OPL_PMULHH, 	EU_AL_14, 		OUT_REG_LAT_2M, 	IN_REG_LAT_F }, // [0x129] == 0x18
    { "PMULHUH", 	OPL_PMULHUH, 	EU_AL_14, 		OUT_REG_LAT_2M, 	IN_REG_LAT_F }, // [0x12a] == 0x1b
    { "PMULLH", 	OPL_PMULLH, 	EU_AL_14, 		OUT_REG_LAT_2M, 	IN_REG_LAT_F }, // [0x12b] == 0x19
    { "PMULUBHH", 	OPL_PMULUBHH, 	EU_AL_14, 		OUT_REG_LAT_2M, 	IN_REG_LAT_F }, // [0x12c] == 0x1d
    { "PORd", 		OPL_PORd, 		EU_AL_0134, 	OUT_REG_LAT_LAST, 	IN_REG_LAT_F }, // [0x12d] == 0x4a
    { "PSADBW", 	OPL_PSADBW, 	EU_AL_14, 		OUT_REG_LAT_1M, 	IN_REG_LAT_F }, // [0x12e] == 0x1c
    { "PSHUFH", 	OPL_PSHUFH, 	EU_AL_14, 		OUT_REG_LAT_1M, 	IN_REG_LAT_F }, // [0x12f] == 0x17
    { "PSHUFW", 	OPL_PSHUFW, 	EU_AL_14, 		OUT_REG_LAT_1M, 	IN_REG_LAT_F }, // [0x130] == 0x16
    { "PSLLD", 		OPL_PSLLD, 		EU_AL_14, 		OUT_REG_LAT_1M, 	IN_REG_LAT_F }, // [0x131] == 0x4e
    { "PSLLH", 		OPL_PSLLH, 		EU_AL_14, 		OUT_REG_LAT_1M, 	IN_REG_LAT_F }, // [0x132] == 0x15
    { "PSLLQH", 	OPL_PSLLQH, 	EU_AL_14, 		OUT_REG_LAT_1M, 	IN_REG_LAT_F }, // [0x133] == 0xe
    { "PSLLQL", 	OPL_PSLLQL, 	EU_AL_14, 		OUT_REG_LAT_1M, 	IN_REG_LAT_F }, // [0x134] == 0xf
    { "PSLLW", 		OPL_PSLLW, 		EU_AL_14, 		OUT_REG_LAT_1M, 	IN_REG_LAT_F }, // [0x135] == 0x14
    { "PSRAH", 		OPL_PSRAH, 		EU_AL_14, 		OUT_REG_LAT_1M, 	IN_REG_LAT_F }, // [0x136] == 0x13
    { "PSRAW", 		OPL_PSRAW, 		EU_AL_14, 		OUT_REG_LAT_1M, 	IN_REG_LAT_F }, // [0x137] == 0x12
    { "PSRLD", 		OPL_PSRLD, 		EU_AL_14, 		OUT_REG_LAT_1M, 	IN_REG_LAT_F }, // [0x138] == 0x4c
    { "PSRLH", 		OPL_PSRLH, 		EU_AL_14, 		OUT_REG_LAT_1M, 	IN_REG_LAT_F }, // [0x139] == 0x11
    { "PSRLQH", 	OPL_PSRLQH, 	EU_AL_14, 		OUT_REG_LAT_1M, 	IN_REG_LAT_F }, // [0x13a] == 0xc
    { "PSRLQL", 	OPL_PSRLQL, 	EU_AL_14, 		OUT_REG_LAT_1M, 	IN_REG_LAT_F }, // [0x13b] == 0xd
    { "PSRLW", 		OPL_PSRLW, 		EU_AL_14, 		OUT_REG_LAT_1M, 	IN_REG_LAT_F }, // [0x13c] == 0x10
    { "PSUBB", 		OPL_PSUBB, 		EU_AL_03, 		OUT_REG_LAT_1M, 	IN_REG_LAT_F }, // [0x13d] == 0x10
    { "PSUBD", 		OPL_PSUBD, 		EU_AL_03, 		OUT_REG_LAT_1M, 	IN_REG_LAT_F }, // [0x13e] == 0x17
    { "PSUBH", 		OPL_PSUBH, 		EU_AL_03, 		OUT_REG_LAT_1M, 	IN_REG_LAT_F }, // [0x13f] == 0x11
    { "PSUBSB", 	OPL_PSUBSB, 	EU_AL_03, 		OUT_REG_LAT_1M, 	IN_REG_LAT_F }, // [0x140] == 0x12
    { "PSUBSH", 	OPL_PSUBSH, 	EU_AL_03, 		OUT_REG_LAT_1M, 	IN_REG_LAT_F }, // [0x141] == 0x13
    { "PSUBUSB", 	OPL_PSUBUSB, 	EU_AL_03, 		OUT_REG_LAT_1M, 	IN_REG_LAT_F }, // [0x142] == 0x14
    { "PSUBUSH", 	OPL_PSUBUSH, 	EU_AL_03, 		OUT_REG_LAT_1M, 	IN_REG_LAT_F }, // [0x143] == 0x15
    { "PSUBW", 		OPL_PSUBW, 		EU_AL_03, 		OUT_REG_LAT_1M, 	IN_REG_LAT_F }, // [0x144] == 0x16
    { "PUNPCKHBH", 	OPL_PUNPCKHBH, 	EU_AL_14, 		OUT_REG_LAT_1M, 	IN_REG_LAT_F }, // [0x145] == 0x0
    { "PUNPCKHHW", 	OPL_PUNPCKHHW, 	EU_AL_14, 		OUT_REG_LAT_1M, 	IN_REG_LAT_F }, // [0x146] == 0x2
    { "PUNPCKHWD", 	OPL_PUNPCKHWD, 	EU_AL_14, 		OUT_REG_LAT_1M, 	IN_REG_LAT_F }, // [0x147] == 0x4
    { "PUNPCKLBH", 	OPL_PUNPCKLBH, 	EU_AL_14, 		OUT_REG_LAT_1M, 	IN_REG_LAT_F }, // [0x148] == 0x1
    { "PUNPCKLHW", 	OPL_PUNPCKLHW, 	EU_AL_14, 		OUT_REG_LAT_1M, 	IN_REG_LAT_F }, // [0x149] == 0x3
    { "PUNPCKLWD", 	OPL_PUNPCKLWD, 	EU_AL_14, 		OUT_REG_LAT_1M, 	IN_REG_LAT_F }, // [0x14a] == 0x5
    { "PUTTAGd", 	OPL_PUTTAGd, 	EU_AL_25, 		OUT_REG_LAT_0I, 	IN_REG_LAT_F }, // [0x14b] == 0xb
    { "PUTTAGs", 	OPL_PUTTAGs, 	EU_AL_25, 		OUT_REG_LAT_0I, 	IN_REG_LAT_F }, // [0x14c] == 0xa
    { "PUTTC", 		OPL_PUTTC, 		EU_AL_03, 		OUT_REG_LAT_LAST, 	IN_REG_LAT_LAST }, // [0x14d] == 0x25
    { "PXORd", 		OPL_PXORd, 		EU_AL_0134, 	OUT_REG_LAT_LAST, 	IN_REG_LAT_LAST }, // [0x14e] == 0x4b
    { "RRd", 		OPL_RRd, 		EU_AL_0, 		OUT_REG_LAT_1A, 	IN_REG_LAT_LAST }, // [0x14f] == 0x3f
    { "RRs", 		OPL_RRs, 		EU_AL_0, 		OUT_REG_LAT_1A, 	IN_REG_LAT_LAST }, // [0x150] == 0x3e
    { "RWd", 		OPL_RWd, 		EU_AL_0, 		OUT_REG_LAT_LAST, 	IN_REG_LAT_I }, // [0x151] == 0x3d
    { "RWs", 		OPL_RWs, 		EU_AL_0, 		OUT_REG_LAT_LAST, 	IN_REG_LAT_I }, // [0x152] == 0x3c
    { "SMULX", 		OPL_SMULX, 		EU_AL_0134, 	OUT_REG_LAT_4F, 	IN_REG_LAT_F }, // [0x153] == 0x23
    { "STAAB", 		OPL_STAAB, 		EU_AL_25, 		OUT_REG_LAT_LAST, 	IN_REG_LAT_S }, // [0x154] == 0x1c
    { "STAAD", 		OPL_STAAD, 		EU_AL_25, 		OUT_REG_LAT_LAST, 	IN_REG_LAT_S }, // [0x155] == 0x1f
    { "STAAH", 		OPL_STAAH, 		EU_AL_25, 		OUT_REG_LAT_LAST, 	IN_REG_LAT_S }, // [0x156] == 0x1d
    { "STAAQ", 		OPL_STAAQ, 		EU_AL_25, 		OUT_REG_LAT_LAST, 	IN_REG_LAT_S }, // [0x157] == 0x3f
    { "STAAW", 		OPL_STAAW, 		EU_AL_25, 		OUT_REG_LAT_LAST, 	IN_REG_LAT_S }, // [0x158] == 0x1e
    { "STAPB", 		OPL_STAPB, 		EU_AL_25, 		OUT_REG_LAT_LAST, 	IN_REG_LAT_S }, // [0x159] == 0x28
    { "STAPD", 		OPL_STAPD, 		EU_AL_25, 		OUT_REG_LAT_LAST, 	IN_REG_LAT_S }, // [0x15a] == 0x2b
    { "STAPH", 		OPL_STAPH, 		EU_AL_25, 		OUT_REG_LAT_LAST, 	IN_REG_LAT_S }, // [0x15b] == 0x29
    { "STAPQ", 		OPL_STAPQ, 		EU_AL_25, 		OUT_REG_LAT_LAST, 	IN_REG_LAT_S }, // [0x15c] == 0x3a
    { "STAPW", 		OPL_STAPW, 		EU_AL_25, 		OUT_REG_LAT_LAST, 	IN_REG_LAT_S }, // [0x15d] == 0x2a
    { "STCSQ", 		OPL_STCSQ, 		EU_AL_25, 		OUT_REG_LAT_LAST, 	IN_REG_LAT_S }, // [0x15e] == 0x2
    { "STDSQ", 		OPL_STDSQ, 		EU_AL_25, 		OUT_REG_LAT_LAST, 	IN_REG_LAT_S }, // [0x15f] == 0x3
    { "STESQ", 		OPL_STESQ, 		EU_AL_25, 		OUT_REG_LAT_LAST, 	IN_REG_LAT_S }, // [0x160] == 0x4
    { "STFSQ", 		OPL_STFSQ, 		EU_AL_25, 		OUT_REG_LAT_LAST, 	IN_REG_LAT_S }, // [0x161] == 0x5
    { "STGDB", 		OPL_STGDB, 		EU_AL_25, 		OUT_REG_LAT_LAST, 	IN_REG_LAT_S }, // [0x162] == 0x24
    { "STGDD", 		OPL_STGDD, 		EU_AL_25, 		OUT_REG_LAT_LAST, 	IN_REG_LAT_S }, // [0x163] == 0x27
    { "STGDH", 		OPL_STGDH, 		EU_AL_25, 		OUT_REG_LAT_LAST, 	IN_REG_LAT_S }, // [0x164] == 0x25
    { "STGDQ", 		OPL_STGDQ, 		EU_AL_25, 		OUT_REG_LAT_LAST, 	IN_REG_LAT_S }, // [0x165] == 0x39
    { "STGDW", 		OPL_STGDW, 		EU_AL_25, 		OUT_REG_LAT_LAST, 	IN_REG_LAT_S }, // [0x166] == 0x26
    { "STGSQ", 		OPL_STGSQ, 		EU_AL_25, 		OUT_REG_LAT_LAST, 	IN_REG_LAT_S }, // [0x167] == 0x6
    { "STODPB", 	OPL_STODPB, 	EU_AL_25, 		OUT_REG_LAT_LAST, 	IN_REG_LAT_S }, // [0x168] == 0x34
    { "STODPD", 	OPL_STODPD, 	EU_AL_25, 		OUT_REG_LAT_LAST, 	IN_REG_LAT_S }, // [0x169] == 0x37
    { "STODPH", 	OPL_STODPH, 	EU_AL_25, 		OUT_REG_LAT_LAST, 	IN_REG_LAT_S }, // [0x16a] == 0x35
    { "STODPQ", 	OPL_STODPQ, 	EU_AL_25, 		OUT_REG_LAT_LAST, 	IN_REG_LAT_S }, // [0x16b] == 0x3d
    { "STODPW", 	OPL_STODPW, 	EU_AL_25, 		OUT_REG_LAT_LAST, 	IN_REG_LAT_S }, // [0x16c] == 0x36
    { "STODRB", 	OPL_STODRB, 	EU_AL_25, 		OUT_REG_LAT_LAST, 	IN_REG_LAT_S }, // [0x16d] == 0x2c
    { "STODRD", 	OPL_STODRD, 	EU_AL_25, 		OUT_REG_LAT_LAST, 	IN_REG_LAT_S }, // [0x16e] == 0x2f
    { "STODRH", 	OPL_STODRH, 	EU_AL_25, 		OUT_REG_LAT_LAST, 	IN_REG_LAT_S }, // [0x16f] == 0x2d
    { "STODRQ", 	OPL_STODRQ, 	EU_AL_25, 		OUT_REG_LAT_LAST, 	IN_REG_LAT_S }, // [0x170] == 0x3b
    { "STODRW", 	OPL_STODRW, 	EU_AL_25, 		OUT_REG_LAT_LAST, 	IN_REG_LAT_S }, // [0x171] == 0x2e
    { "STODWB", 	OPL_STODWB, 	EU_AL_25, 		OUT_REG_LAT_LAST, 	IN_REG_LAT_S }, // [0x172] == 0x30
    { "STODWD", 	OPL_STODWD, 	EU_AL_25, 		OUT_REG_LAT_LAST, 	IN_REG_LAT_S }, // [0x173] == 0x33
    { "STODWH", 	OPL_STODWH, 	EU_AL_25, 		OUT_REG_LAT_LAST, 	IN_REG_LAT_S }, // [0x174] == 0x31
    { "STODWQ", 	OPL_STODWQ, 	EU_AL_25, 		OUT_REG_LAT_LAST, 	IN_REG_LAT_S }, // [0x175] == 0x3c
    { "STODWW", 	OPL_STODWW, 	EU_AL_25, 		OUT_REG_LAT_LAST, 	IN_REG_LAT_S }, // [0x176] == 0x32
    { "STRD", 		OPL_STRD, 		EU_AL_25, 		OUT_REG_LAT_LAST, 	IN_REG_LAT_S }, // [0x177] == 0x1b
    { "STSSQ", 		OPL_STSSQ, 		EU_AL_25, 		OUT_REG_LAT_LAST, 	IN_REG_LAT_S }, // [0x178] == 0x7
    { "TDTOMP", 	OPL_TDTOMP, 	EU_AL_0134, 	OUT_REG_LAT_1A, 	IN_REG_LAT_F }, // [0x179] == 0x53
    { "UMULX", 		OPL_UMULX, 		EU_AL_0134, 	OUT_REG_LAT_4F, 	IN_REG_LAT_F }, // [0x17a] == 0x22
    { "FDTOIFD", 	OPL_FDTOIFd,	EU_AL_0134, 	OUT_REG_LAT_4F, 	IN_REG_LAT_F }, // [0x17b] == 0x6d
    { "LAST", 		OPC_LAST, 		EU_LAST, 		OUT_REG_LAT_LAST, 	IN_REG_LAT_LAST }, // [0x17b] == 0xff
    { "OP_CT", 		OPC_LAST, 		EU_LAST, 		OUT_REG_LAT_LAST, 	IN_REG_LAT_CT }, // [0x17b] == 0xff
    { "OP_CALL", 	OPC_LAST, 		EU_LAST, 		OUT_REG_LAT_LAST, 	IN_REG_LAT_CT }, // [0x17b] == 0xff
    { "OP_RLP", 	OPC_LAST, 		EU_LAST, 		OUT_REG_LAT_PRI, 	IN_REG_LAT_LAST }, // [0x17b] == 0xff
    { "OP_ELP", 	OPC_LAST, 		EU_LAST, 		OUT_REG_LAT_PRI, 	IN_REG_LAT_LAST }, // [0x17b] == 0xff
    { "OP_RETURN", 	OPC_LAST, 		EU_LAST, 		OUT_REG_LAT_CT, 	IN_REG_LAT_LAST }, // [0x17b] == 0xff
    { "OP_DISP", 	OPC_LAST, 		EU_LAST, 		OUT_REG_LAT_CT, 	IN_REG_LAT_LAST }, // [0x17b] == 0xff
};
} // namespace asm_e2k

#endif // OPCODES_E2K_CC
