#ifndef ASM_E2K_REGISTERS_H
#define ASM_E2K_REGISTERS_H

#ifdef __cplusplus
namespace asm_e2k {
#endif

typedef enum {
    PredicatesCount = 32,
#ifdef V8_TARGET_ARCH_E2K
    PredicatesUsedCount = 32,
#else
    PredicatesUsedCount = 6,
#endif
    PXRegister = 1,
    PredicatesTotalNum = PredicatesUsedCount + PXRegister,
    StackRegistersCount = 64,
    RotatedRegistersCount = 128,
    ArgRegistersCount = 8,
    GlobalRegistersCount = 16,
    ScratchRegistersCount = 16,
    ControlRegistersCount = 3,
    TotalRegCount = PredicatesCount +
    PXRegister +
    StackRegistersCount +
    RotatedRegistersCount +
    GlobalRegistersCount +
    ScratchRegistersCount +
    ControlRegistersCount,
    PredicateThreadsNum = (PredicatesUsedCount * 2) + PXRegister,
} RegCount;

typedef enum RegCode {
    EREG_G0,  EREG_G1,  EREG_G2,  EREG_G3,  EREG_G4,  EREG_G5,  EREG_G6,  EREG_G7,  EREG_G8,  EREG_G9,
    EREG_G10, EREG_G11, EREG_G12, EREG_G13, EREG_G14, EREG_G15, EREG_G16, EREG_G17, EREG_G18, EREG_G19,
    EREG_G20, EREG_G21, EREG_G22, EREG_G23, EREG_G24, EREG_G25, EREG_G26, EREG_G27, EREG_G28, EREG_G29,
    EREG_G30, EREG_G31,

    EREG_R0,  EREG_R1,  EREG_R2,  EREG_R3,  EREG_R4,  EREG_R5,  EREG_R6,  EREG_R7,  EREG_R8,  EREG_R9,
    EREG_R10, EREG_R11, EREG_R12, EREG_R13, EREG_R14, EREG_R15, EREG_R16, EREG_R17, EREG_R18, EREG_R19,
    EREG_R20, EREG_R21, EREG_R22, EREG_R23, EREG_R24, EREG_R25, EREG_R26, EREG_R27, EREG_R28, EREG_R29,
    EREG_R30, EREG_R31, EREG_R32, EREG_R33, EREG_R34, EREG_R35, EREG_R36, EREG_R37, EREG_R38, EREG_R39,
    EREG_R40, EREG_R41, EREG_R42, EREG_R43, EREG_R44, EREG_R45, EREG_R46, EREG_R47, EREG_R48, EREG_R49,
    EREG_R50, EREG_R51, EREG_R52, EREG_R53, EREG_R54, EREG_R55, EREG_R56, EREG_R57, EREG_R58, EREG_R59,
    EREG_R60, EREG_R61, EREG_R62, EREG_R63,

    EREG_BR0,   EREG_BR1,   EREG_BR2,   EREG_BR3,   EREG_BR4,   EREG_BR5,   EREG_BR6,   EREG_BR7,   EREG_BR8,   EREG_BR9,
    EREG_BR10,  EREG_BR11,  EREG_BR12,  EREG_BR13,  EREG_BR14,  EREG_BR15,  EREG_BR16,  EREG_BR17,  EREG_BR18,  EREG_BR19,
    EREG_BR20,  EREG_BR21,  EREG_BR22,  EREG_BR23,  EREG_BR24,  EREG_BR25,  EREG_BR26,  EREG_BR27,  EREG_BR28,  EREG_BR29,
    EREG_BR30,  EREG_BR31,  EREG_BR32,  EREG_BR33,  EREG_BR34,  EREG_BR35,  EREG_BR36,  EREG_BR37,  EREG_BR38,  EREG_BR39,
    EREG_BR40,  EREG_BR41,  EREG_BR42,  EREG_BR43,  EREG_BR44,  EREG_BR45,  EREG_BR46,  EREG_BR47,  EREG_BR48,  EREG_BR49,
    EREG_BR50,  EREG_BR51,  EREG_BR52,  EREG_BR53,  EREG_BR54,  EREG_BR55,  EREG_BR56,  EREG_BR57,  EREG_BR58,  EREG_BR59,
    EREG_BR60,  EREG_BR61,  EREG_BR62,  EREG_BR63,  EREG_BR64,  EREG_BR65,  EREG_BR66,  EREG_BR67,  EREG_BR68,  EREG_BR69,
    EREG_BR70,  EREG_BR71,  EREG_BR72,  EREG_BR73,  EREG_BR74,  EREG_BR75,  EREG_BR76,  EREG_BR77,  EREG_BR78,  EREG_BR79,
    EREG_BR80,  EREG_BR81,  EREG_BR82,  EREG_BR83,  EREG_BR84,  EREG_BR85,  EREG_BR86,  EREG_BR87,  EREG_BR88,  EREG_BR89,
    EREG_BR90,  EREG_BR91,  EREG_BR92,  EREG_BR93,  EREG_BR94,  EREG_BR95,  EREG_BR96,  EREG_BR97,  EREG_BR98,  EREG_BR99,
    EREG_BR100, EREG_BR101, EREG_BR102, EREG_BR103, EREG_BR104, EREG_BR105, EREG_BR106, EREG_BR107, EREG_BR108, EREG_BR109,
    EREG_BR110, EREG_BR111, EREG_BR112, EREG_BR113, EREG_BR114, EREG_BR115, EREG_BR116, EREG_BR117, EREG_BR118, EREG_BR119,
    EREG_BR120, EREG_BR121, EREG_BR122, EREG_BR123, EREG_BR124, EREG_BR125, EREG_BR126, EREG_BR127,

    EREG_PR0,  EREG_PR1,  EREG_PR2,  EREG_PR3,  EREG_PR4,  EREG_PR5,  EREG_PR6,  EREG_PR7,  EREG_PR8,  EREG_PR9,
    EREG_PR10, EREG_PR11, EREG_PR12, EREG_PR13, EREG_PR14, EREG_PR15, EREG_PR16, EREG_PR17, EREG_PR18, EREG_PR19,
    EREG_PR20, EREG_PR21, EREG_PR22, EREG_PR23, EREG_PR24, EREG_PR25, EREG_PR26, EREG_PR27, EREG_PR28, EREG_PR29,
    EREG_PR30, EREG_PR31, EREG_PRX,

    EREG_CTPR1, EREG_CTPR2, EREG_CTPR3,

    EREG_EMPTY_LO, EREG_EMPTY_HI,

    EREG_LAST,

    EREG_INVALID = -1
} RegCode;

typedef enum ElbrusCURegister {
    PSR = 0x0,
    WD = 0x1,
    CWD = 0x6,
    PSP_hi = 0x7,
    PSP_lo = 0x9,
    PSHTP = 0x0b,
    PCSP_hi = 0x0d,
    PCSP_lo = 0x0f,
    PCSHTP = 0x13,
    CTPR1 = 0x15,
    CTPR2 = 0x16,
    CTPR3 = 0x17,
    USBR = 0x1e,
    CUTD = 0x21,
    EIR = 0x23,
    TSD = 0x24,
    CUIR = 0x25,
    OSCUD_hi = 0x26,
    OSCUD_lo = 0x27,
    OSGD_hi = 0x28,
    OSGD_lo = 0x29,
    OSEM = 0x2a,
    USD_hi = 0x2c,
    USD_lo = 0x2d,
    TR = 0x2e,
    OSR0 = 0x2f,
    CUD_hi = 0x30,
    CUD_lo = 0x31,
    GD_hi = 0x32,
    GD_lo = 0x33,
    CS_hi = 0x34,
    CS_lo = 0x35,
    DS_hi = 0x36,
    DS_lo = 0x37,
    ES_hi = 0x38,
    ES_lo = 0x39,
    FS_hi = 0x3a,
    FS_lo = 0x3b,
    GS_hi = 0x3c,
    GS_lo = 0x3d,
    SS_hi = 0x3e,
    SS_lo = 0x3f,
    DIBCR = 0x40,
    DIMCR = 0x41,
    DIBSR = 0x42,
    DTCR = 0x43,
    DIBAR0 = 0x48,
    DIBAR1 = 0x49,
    DIBAR2 = 0x4a,
    DIBAR3 = 0x4b,
    DIMAR0 = 0x4c,
    DIMAR1 = 0x4d,
    DTARF = 0x4e,
    DTART = 0x4f,
    CF_CWD_0__hi = 0x51,
    CF_CWD_0__lo = 0x53,
    CF_CWD_16__hi = 0x55,
    CF_CWD_16__lo = 0x57,
    CU_HW0 = 0x78,
    UPSR = 0x80,
    IP = 0x81,
    nIP = 0x82,
    LSR = 0x83,
    PFPFR = 0x84,
    FPCR = 0x85,
    FPSR = 0x86,
    ILCR = 0x87,
    BR = 0x88,
    BGR = 0x89,
    IDR = 0x8a,
    CLKR = 0x90,
    TIR_hi = 0x9c,
    TIR_lo = 0x9d,
    RPR_lo = 0xa0,
    SBBP = 0xa1,
    RPR_hi = 0xa2
} ElbrusCURegister;

#ifdef __cplusplus
} // namespace asm_e2k
#endif

#endif // ASM_E2K_REGISTERS_H

